agentle.mcp.resources.resource\_description\_with\_template
===========================================================

.. automodule:: agentle.mcp.resources.resource_description_with_template

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      ResourceDescriptionWithTemplate
   